@@ -51,7 +51,6 @@ class GifSaveOptionsData(object):
         'file_name': 'str',
         'flat_opc_xml_mapping_only': 'bool',
         'iml_rendering_mode': 'str',
-        'save_format': 'str',
         'update_created_time_property': 'bool',
         'update_fields': 'bool',
         'update_last_printed_property': 'bool',
@@ -76,7 +75,8 @@ class GifSaveOptionsData(object):
         'use_anti_aliasing': 'bool',
         'use_gdi_emf_renderer': 'bool',
         'use_high_quality_rendering': 'bool',
-        'vertical_resolution': 'float'
+        'vertical_resolution': 'float',
+        'save_format': 'str'
     }
 
     attribute_map = {
@@ -88,7 +88,6 @@ class GifSaveOptionsData(object):
         'file_name': 'FileName',
         'flat_opc_xml_mapping_only': 'FlatOpcXmlMappingOnly',
         'iml_rendering_mode': 'ImlRenderingMode',
-        'save_format': 'SaveFormat',
         'update_created_time_property': 'UpdateCreatedTimeProperty',
         'update_fields': 'UpdateFields',
         'update_last_printed_property': 'UpdateLastPrintedProperty',
@@ -113,10 +112,11 @@ class GifSaveOptionsData(object):
         'use_anti_aliasing': 'UseAntiAliasing',
         'use_gdi_emf_renderer': 'UseGdiEmfRenderer',
         'use_high_quality_rendering': 'UseHighQualityRendering',
-        'vertical_resolution': 'VerticalResolution'
+        'vertical_resolution': 'VerticalResolution',
+        'save_format': 'SaveFormat'
     }
 
-    def __init__(self, allow_embedding_post_script_fonts=None, custom_time_zone_info_data=None, dml3_d_effects_rendering_mode=None, dml_effects_rendering_mode=None, dml_rendering_mode=None, file_name=None, flat_opc_xml_mapping_only=None, iml_rendering_mode=None, save_format=None, update_created_time_property=None, update_fields=None, update_last_printed_property=None, update_last_saved_time_property=None, update_sdt_content=None, zip_output=None, color_mode=None, jpeg_quality=None, metafile_rendering_options=None, numeral_format=None, optimize_output=None, page_count=None, page_index=None, horizontal_resolution=None, image_brightness=None, image_color_mode=None, image_contrast=None, paper_color=None, pixel_format=None, resolution=None, scale=None, use_anti_aliasing=None, use_gdi_emf_renderer=None, use_high_quality_rendering=None, vertical_resolution=None):  # noqa: E501
+    def __init__(self, allow_embedding_post_script_fonts=None, custom_time_zone_info_data=None, dml3_d_effects_rendering_mode=None, dml_effects_rendering_mode=None, dml_rendering_mode=None, file_name=None, flat_opc_xml_mapping_only=None, iml_rendering_mode=None, update_created_time_property=None, update_fields=None, update_last_printed_property=None, update_last_saved_time_property=None, update_sdt_content=None, zip_output=None, color_mode=None, jpeg_quality=None, metafile_rendering_options=None, numeral_format=None, optimize_output=None, page_count=None, page_index=None, horizontal_resolution=None, image_brightness=None, image_color_mode=None, image_contrast=None, paper_color=None, pixel_format=None, resolution=None, scale=None, use_anti_aliasing=None, use_gdi_emf_renderer=None, use_high_quality_rendering=None, vertical_resolution=None):  # noqa: E501
         """GifSaveOptionsData - a model defined in Swagger"""  # noqa: E501
 
         self._allow_embedding_post_script_fonts = None
@@ -127,7 +127,6 @@ class GifSaveOptionsData(object):
         self._file_name = None
         self._flat_opc_xml_mapping_only = None
         self._iml_rendering_mode = None
-        self._save_format = None
         self._update_created_time_property = None
         self._update_fields = None
         self._update_last_printed_property = None
@@ -153,6 +152,7 @@ class GifSaveOptionsData(object):
         self._use_gdi_emf_renderer = None
         self._use_high_quality_rendering = None
         self._vertical_resolution = None
+        self._save_format = "gif"
         self.discriminator = None
 
         if allow_embedding_post_script_fonts is not None:
@@ -171,8 +171,6 @@ class GifSaveOptionsData(object):
             self.flat_opc_xml_mapping_only = flat_opc_xml_mapping_only
         if iml_rendering_mode is not None:
             self.iml_rendering_mode = iml_rendering_mode
-        if save_format is not None:
-            self.save_format = save_format
         if update_created_time_property is not None:
             self.update_created_time_property = update_created_time_property
         if update_fields is not None:
@@ -318,7 +316,15 @@ class GifSaveOptionsData(object):
         :param dml_effects_rendering_mode: The dml_effects_rendering_mode of this GifSaveOptionsData.  # noqa: E501
         :type: str
         """
-        self._dml_effects_rendering_mode = dml_effects_rendering_mode
+        allowed_values = ["Simplified", "None", "Fine"]  # noqa: E501
+        if not dml_effects_rendering_mode.isdigit():
+            if dml_effects_rendering_mode not in allowed_values:
+                raise ValueError(
+                    "Invalid value for `dml_effects_rendering_mode` ({0}), must be one of {1}"  # noqa: E501
+                    .format(dml_effects_rendering_mode, allowed_values))
+            self._dml_effects_rendering_mode = dml_effects_rendering_mode
+        else:
+            self._dml_effects_rendering_mode = allowed_values[int(dml_effects_rendering_mode) if six.PY3 else long(dml_effects_rendering_mode)]
 
     @property
     def dml_rendering_mode(self):
@@ -340,7 +346,15 @@ class GifSaveOptionsData(object):
         :param dml_rendering_mode: The dml_rendering_mode of this GifSaveOptionsData.  # noqa: E501
         :type: str
         """
-        self._dml_rendering_mode = dml_rendering_mode
+        allowed_values = ["Fallback", "DrawingML"]  # noqa: E501
+        if not dml_rendering_mode.isdigit():
+            if dml_rendering_mode not in allowed_values:
+                raise ValueError(
+                    "Invalid value for `dml_rendering_mode` ({0}), must be one of {1}"  # noqa: E501
+                    .format(dml_rendering_mode, allowed_values))
+            self._dml_rendering_mode = dml_rendering_mode
+        else:
+            self._dml_rendering_mode = allowed_values[int(dml_rendering_mode) if six.PY3 else long(dml_rendering_mode)]
 
     @property
     def file_name(self):
@@ -406,29 +420,15 @@ class GifSaveOptionsData(object):
         :param iml_rendering_mode: The iml_rendering_mode of this GifSaveOptionsData.  # noqa: E501
         :type: str
         """
-        self._iml_rendering_mode = iml_rendering_mode
-
-    @property
-    def save_format(self):
-        """Gets the save_format of this GifSaveOptionsData.  # noqa: E501
-
-        Gets or sets the format of save.  # noqa: E501
-
-        :return: The save_format of this GifSaveOptionsData.  # noqa: E501
-        :rtype: str
-        """
-        return self._save_format
-
-    @save_format.setter
-    def save_format(self, save_format):
-        """Sets the save_format of this GifSaveOptionsData.
-
-        Gets or sets the format of save.  # noqa: E501
-
-        :param save_format: The save_format of this GifSaveOptionsData.  # noqa: E501
-        :type: str
-        """
-        self._save_format = save_format
+        allowed_values = ["Fallback", "InkML"]  # noqa: E501
+        if not iml_rendering_mode.isdigit():
+            if iml_rendering_mode not in allowed_values:
+                raise ValueError(
+                    "Invalid value for `iml_rendering_mode` ({0}), must be one of {1}"  # noqa: E501
+                    .format(iml_rendering_mode, allowed_values))
+            self._iml_rendering_mode = iml_rendering_mode
+        else:
+            self._iml_rendering_mode = allowed_values[int(iml_rendering_mode) if six.PY3 else long(iml_rendering_mode)]
 
     @property
     def update_created_time_property(self):
@@ -582,7 +582,15 @@ class GifSaveOptionsData(object):
         :param color_mode: The color_mode of this GifSaveOptionsData.  # noqa: E501
         :type: str
         """
-        self._color_mode = color_mode
+        allowed_values = ["Normal", "Grayscale"]  # noqa: E501
+        if not color_mode.isdigit():
+            if color_mode not in allowed_values:
+                raise ValueError(
+                    "Invalid value for `color_mode` ({0}), must be one of {1}"  # noqa: E501
+                    .format(color_mode, allowed_values))
+            self._color_mode = color_mode
+        else:
+            self._color_mode = allowed_values[int(color_mode) if six.PY3 else long(color_mode)]
 
     @property
     def jpeg_quality(self):
@@ -648,7 +656,15 @@ class GifSaveOptionsData(object):
         :param numeral_format: The numeral_format of this GifSaveOptionsData.  # noqa: E501
         :type: str
         """
-        self._numeral_format = numeral_format
+        allowed_values = ["European", "ArabicIndic", "EasternArabicIndic", "Context", "System"]  # noqa: E501
+        if not numeral_format.isdigit():
+            if numeral_format not in allowed_values:
+                raise ValueError(
+                    "Invalid value for `numeral_format` ({0}), must be one of {1}"  # noqa: E501
+                    .format(numeral_format, allowed_values))
+            self._numeral_format = numeral_format
+        else:
+            self._numeral_format = allowed_values[int(numeral_format) if six.PY3 else long(numeral_format)]
 
     @property
     def optimize_output(self):
@@ -780,7 +796,15 @@ class GifSaveOptionsData(object):
         :param image_color_mode: The image_color_mode of this GifSaveOptionsData.  # noqa: E501
         :type: str
         """
-        self._image_color_mode = image_color_mode
+        allowed_values = ["None", "Grayscale", "BlackAndWhite"]  # noqa: E501
+        if not image_color_mode.isdigit():
+            if image_color_mode not in allowed_values:
+                raise ValueError(
+                    "Invalid value for `image_color_mode` ({0}), must be one of {1}"  # noqa: E501
+                    .format(image_color_mode, allowed_values))
+            self._image_color_mode = image_color_mode
+        else:
+            self._image_color_mode = allowed_values[int(image_color_mode) if six.PY3 else long(image_color_mode)]
 
     @property
     def image_contrast(self):
@@ -846,7 +870,15 @@ class GifSaveOptionsData(object):
         :param pixel_format: The pixel_format of this GifSaveOptionsData.  # noqa: E501
         :type: str
         """
-        self._pixel_format = pixel_format
+        allowed_values = ["Format16BppRgb555", "Format16BppRgb565", "Format16BppArgb1555", "Format24BppRgb", "Format32BppRgb", "Format32BppArgb", "Format32BppPArgb", "Format48BppRgb", "Format64BppArgb", "Format64BppPArgb", "Format1bppIndexed"]  # noqa: E501
+        if not pixel_format.isdigit():
+            if pixel_format not in allowed_values:
+                raise ValueError(
+                    "Invalid value for `pixel_format` ({0}), must be one of {1}"  # noqa: E501
+                    .format(pixel_format, allowed_values))
+            self._pixel_format = pixel_format
+        else:
+            self._pixel_format = allowed_values[int(pixel_format) if six.PY3 else long(pixel_format)]
 
     @property
     def resolution(self):
@@ -980,6 +1012,18 @@ class GifSaveOptionsData(object):
         """
         self._vertical_resolution = vertical_resolution
 
+    @property
+    def save_format(self):
+        """Gets the save_format of this GifSaveOptionsData.  # noqa: E501
+
+        Gets the format of save.  # noqa: E501
+
+        :return: The save_format of this GifSaveOptionsData.  # noqa: E501
+        :rtype: str
+        """
+        return self._save_format
+
+
 
     def to_dict(self):
         """Returns the model properties as a dict"""
