@@ -51,7 +51,6 @@ class HtmlFixedSaveOptionsData(object):
         'file_name': 'str',
         'flat_opc_xml_mapping_only': 'bool',
         'iml_rendering_mode': 'str',
-        'save_format': 'str',
         'update_created_time_property': 'bool',
         'update_fields': 'bool',
         'update_last_printed_property': 'bool',
@@ -77,6 +76,7 @@ class HtmlFixedSaveOptionsData(object):
         'resources_folder': 'str',
         'resources_folder_alias': 'str',
         'save_font_face_css_separately': 'bool',
+        'save_format': 'str',
         'show_page_border': 'bool',
         'use_target_machine_fonts': 'bool'
     }
@@ -90,7 +90,6 @@ class HtmlFixedSaveOptionsData(object):
         'file_name': 'FileName',
         'flat_opc_xml_mapping_only': 'FlatOpcXmlMappingOnly',
         'iml_rendering_mode': 'ImlRenderingMode',
-        'save_format': 'SaveFormat',
         'update_created_time_property': 'UpdateCreatedTimeProperty',
         'update_fields': 'UpdateFields',
         'update_last_printed_property': 'UpdateLastPrintedProperty',
@@ -116,11 +115,12 @@ class HtmlFixedSaveOptionsData(object):
         'resources_folder': 'ResourcesFolder',
         'resources_folder_alias': 'ResourcesFolderAlias',
         'save_font_face_css_separately': 'SaveFontFaceCssSeparately',
+        'save_format': 'SaveFormat',
         'show_page_border': 'ShowPageBorder',
         'use_target_machine_fonts': 'UseTargetMachineFonts'
     }
 
-    def __init__(self, allow_embedding_post_script_fonts=None, custom_time_zone_info_data=None, dml3_d_effects_rendering_mode=None, dml_effects_rendering_mode=None, dml_rendering_mode=None, file_name=None, flat_opc_xml_mapping_only=None, iml_rendering_mode=None, save_format=None, update_created_time_property=None, update_fields=None, update_last_printed_property=None, update_last_saved_time_property=None, update_sdt_content=None, zip_output=None, color_mode=None, jpeg_quality=None, metafile_rendering_options=None, numeral_format=None, optimize_output=None, page_count=None, page_index=None, css_class_names_prefix=None, encoding=None, export_embedded_css=None, export_embedded_fonts=None, export_embedded_images=None, export_form_fields=None, font_format=None, page_horizontal_alignment=None, page_margins=None, resources_folder=None, resources_folder_alias=None, save_font_face_css_separately=None, show_page_border=None, use_target_machine_fonts=None):  # noqa: E501
+    def __init__(self, allow_embedding_post_script_fonts=None, custom_time_zone_info_data=None, dml3_d_effects_rendering_mode=None, dml_effects_rendering_mode=None, dml_rendering_mode=None, file_name=None, flat_opc_xml_mapping_only=None, iml_rendering_mode=None, update_created_time_property=None, update_fields=None, update_last_printed_property=None, update_last_saved_time_property=None, update_sdt_content=None, zip_output=None, color_mode=None, jpeg_quality=None, metafile_rendering_options=None, numeral_format=None, optimize_output=None, page_count=None, page_index=None, css_class_names_prefix=None, encoding=None, export_embedded_css=None, export_embedded_fonts=None, export_embedded_images=None, export_form_fields=None, font_format=None, page_horizontal_alignment=None, page_margins=None, resources_folder=None, resources_folder_alias=None, save_font_face_css_separately=None, show_page_border=None, use_target_machine_fonts=None):  # noqa: E501
         """HtmlFixedSaveOptionsData - a model defined in Swagger"""  # noqa: E501
 
         self._allow_embedding_post_script_fonts = None
@@ -131,7 +131,6 @@ class HtmlFixedSaveOptionsData(object):
         self._file_name = None
         self._flat_opc_xml_mapping_only = None
         self._iml_rendering_mode = None
-        self._save_format = None
         self._update_created_time_property = None
         self._update_fields = None
         self._update_last_printed_property = None
@@ -157,6 +156,7 @@ class HtmlFixedSaveOptionsData(object):
         self._resources_folder = None
         self._resources_folder_alias = None
         self._save_font_face_css_separately = None
+        self._save_format = "htmlfixed"
         self._show_page_border = None
         self._use_target_machine_fonts = None
         self.discriminator = None
@@ -177,8 +177,6 @@ class HtmlFixedSaveOptionsData(object):
             self.flat_opc_xml_mapping_only = flat_opc_xml_mapping_only
         if iml_rendering_mode is not None:
             self.iml_rendering_mode = iml_rendering_mode
-        if save_format is not None:
-            self.save_format = save_format
         if update_created_time_property is not None:
             self.update_created_time_property = update_created_time_property
         if update_fields is not None:
@@ -328,7 +326,15 @@ class HtmlFixedSaveOptionsData(object):
         :param dml_effects_rendering_mode: The dml_effects_rendering_mode of this HtmlFixedSaveOptionsData.  # noqa: E501
         :type: str
         """
-        self._dml_effects_rendering_mode = dml_effects_rendering_mode
+        allowed_values = ["Simplified", "None", "Fine"]  # noqa: E501
+        if not dml_effects_rendering_mode.isdigit():
+            if dml_effects_rendering_mode not in allowed_values:
+                raise ValueError(
+                    "Invalid value for `dml_effects_rendering_mode` ({0}), must be one of {1}"  # noqa: E501
+                    .format(dml_effects_rendering_mode, allowed_values))
+            self._dml_effects_rendering_mode = dml_effects_rendering_mode
+        else:
+            self._dml_effects_rendering_mode = allowed_values[int(dml_effects_rendering_mode) if six.PY3 else long(dml_effects_rendering_mode)]
 
     @property
     def dml_rendering_mode(self):
@@ -350,7 +356,15 @@ class HtmlFixedSaveOptionsData(object):
         :param dml_rendering_mode: The dml_rendering_mode of this HtmlFixedSaveOptionsData.  # noqa: E501
         :type: str
         """
-        self._dml_rendering_mode = dml_rendering_mode
+        allowed_values = ["Fallback", "DrawingML"]  # noqa: E501
+        if not dml_rendering_mode.isdigit():
+            if dml_rendering_mode not in allowed_values:
+                raise ValueError(
+                    "Invalid value for `dml_rendering_mode` ({0}), must be one of {1}"  # noqa: E501
+                    .format(dml_rendering_mode, allowed_values))
+            self._dml_rendering_mode = dml_rendering_mode
+        else:
+            self._dml_rendering_mode = allowed_values[int(dml_rendering_mode) if six.PY3 else long(dml_rendering_mode)]
 
     @property
     def file_name(self):
@@ -416,29 +430,15 @@ class HtmlFixedSaveOptionsData(object):
         :param iml_rendering_mode: The iml_rendering_mode of this HtmlFixedSaveOptionsData.  # noqa: E501
         :type: str
         """
-        self._iml_rendering_mode = iml_rendering_mode
-
-    @property
-    def save_format(self):
-        """Gets the save_format of this HtmlFixedSaveOptionsData.  # noqa: E501
-
-        Gets or sets the format of save.  # noqa: E501
-
-        :return: The save_format of this HtmlFixedSaveOptionsData.  # noqa: E501
-        :rtype: str
-        """
-        return self._save_format
-
-    @save_format.setter
-    def save_format(self, save_format):
-        """Sets the save_format of this HtmlFixedSaveOptionsData.
-
-        Gets or sets the format of save.  # noqa: E501
-
-        :param save_format: The save_format of this HtmlFixedSaveOptionsData.  # noqa: E501
-        :type: str
-        """
-        self._save_format = save_format
+        allowed_values = ["Fallback", "InkML"]  # noqa: E501
+        if not iml_rendering_mode.isdigit():
+            if iml_rendering_mode not in allowed_values:
+                raise ValueError(
+                    "Invalid value for `iml_rendering_mode` ({0}), must be one of {1}"  # noqa: E501
+                    .format(iml_rendering_mode, allowed_values))
+            self._iml_rendering_mode = iml_rendering_mode
+        else:
+            self._iml_rendering_mode = allowed_values[int(iml_rendering_mode) if six.PY3 else long(iml_rendering_mode)]
 
     @property
     def update_created_time_property(self):
@@ -592,7 +592,15 @@ class HtmlFixedSaveOptionsData(object):
         :param color_mode: The color_mode of this HtmlFixedSaveOptionsData.  # noqa: E501
         :type: str
         """
-        self._color_mode = color_mode
+        allowed_values = ["Normal", "Grayscale"]  # noqa: E501
+        if not color_mode.isdigit():
+            if color_mode not in allowed_values:
+                raise ValueError(
+                    "Invalid value for `color_mode` ({0}), must be one of {1}"  # noqa: E501
+                    .format(color_mode, allowed_values))
+            self._color_mode = color_mode
+        else:
+            self._color_mode = allowed_values[int(color_mode) if six.PY3 else long(color_mode)]
 
     @property
     def jpeg_quality(self):
@@ -658,7 +666,15 @@ class HtmlFixedSaveOptionsData(object):
         :param numeral_format: The numeral_format of this HtmlFixedSaveOptionsData.  # noqa: E501
         :type: str
         """
-        self._numeral_format = numeral_format
+        allowed_values = ["European", "ArabicIndic", "EasternArabicIndic", "Context", "System"]  # noqa: E501
+        if not numeral_format.isdigit():
+            if numeral_format not in allowed_values:
+                raise ValueError(
+                    "Invalid value for `numeral_format` ({0}), must be one of {1}"  # noqa: E501
+                    .format(numeral_format, allowed_values))
+            self._numeral_format = numeral_format
+        else:
+            self._numeral_format = allowed_values[int(numeral_format) if six.PY3 else long(numeral_format)]
 
     @property
     def optimize_output(self):
@@ -878,7 +894,15 @@ class HtmlFixedSaveOptionsData(object):
         :param font_format: The font_format of this HtmlFixedSaveOptionsData.  # noqa: E501
         :type: str
         """
-        self._font_format = font_format
+        allowed_values = ["Woff", "Ttf"]  # noqa: E501
+        if not font_format.isdigit():
+            if font_format not in allowed_values:
+                raise ValueError(
+                    "Invalid value for `font_format` ({0}), must be one of {1}"  # noqa: E501
+                    .format(font_format, allowed_values))
+            self._font_format = font_format
+        else:
+            self._font_format = allowed_values[int(font_format) if six.PY3 else long(font_format)]
 
     @property
     def page_horizontal_alignment(self):
@@ -900,7 +924,15 @@ class HtmlFixedSaveOptionsData(object):
         :param page_horizontal_alignment: The page_horizontal_alignment of this HtmlFixedSaveOptionsData.  # noqa: E501
         :type: str
         """
-        self._page_horizontal_alignment = page_horizontal_alignment
+        allowed_values = ["Left", "Center", "Right"]  # noqa: E501
+        if not page_horizontal_alignment.isdigit():
+            if page_horizontal_alignment not in allowed_values:
+                raise ValueError(
+                    "Invalid value for `page_horizontal_alignment` ({0}), must be one of {1}"  # noqa: E501
+                    .format(page_horizontal_alignment, allowed_values))
+            self._page_horizontal_alignment = page_horizontal_alignment
+        else:
+            self._page_horizontal_alignment = allowed_values[int(page_horizontal_alignment) if six.PY3 else long(page_horizontal_alignment)]
 
     @property
     def page_margins(self):
@@ -990,6 +1022,18 @@ class HtmlFixedSaveOptionsData(object):
         """
         self._save_font_face_css_separately = save_font_face_css_separately
 
+    @property
+    def save_format(self):
+        """Gets the save_format of this HtmlFixedSaveOptionsData.  # noqa: E501
+
+        Gets the format of save.  # noqa: E501
+
+        :return: The save_format of this HtmlFixedSaveOptionsData.  # noqa: E501
+        :rtype: str
+        """
+        return self._save_format
+
+
     @property
     def show_page_border(self):
         """Gets the show_page_border of this HtmlFixedSaveOptionsData.  # noqa: E501
