@@ -51,7 +51,6 @@ class PsSaveOptionsData(object):
         'file_name': 'str',
         'flat_opc_xml_mapping_only': 'bool',
         'iml_rendering_mode': 'str',
-        'save_format': 'str',
         'update_created_time_property': 'bool',
         'update_fields': 'bool',
         'update_last_printed_property': 'bool',
@@ -65,6 +64,7 @@ class PsSaveOptionsData(object):
         'optimize_output': 'bool',
         'page_count': 'int',
         'page_index': 'int',
+        'save_format': 'str',
         'use_book_fold_printing_settings': 'bool'
     }
 
@@ -77,7 +77,6 @@ class PsSaveOptionsData(object):
         'file_name': 'FileName',
         'flat_opc_xml_mapping_only': 'FlatOpcXmlMappingOnly',
         'iml_rendering_mode': 'ImlRenderingMode',
-        'save_format': 'SaveFormat',
         'update_created_time_property': 'UpdateCreatedTimeProperty',
         'update_fields': 'UpdateFields',
         'update_last_printed_property': 'UpdateLastPrintedProperty',
@@ -91,10 +90,11 @@ class PsSaveOptionsData(object):
         'optimize_output': 'OptimizeOutput',
         'page_count': 'PageCount',
         'page_index': 'PageIndex',
+        'save_format': 'SaveFormat',
         'use_book_fold_printing_settings': 'UseBookFoldPrintingSettings'
     }
 
-    def __init__(self, allow_embedding_post_script_fonts=None, custom_time_zone_info_data=None, dml3_d_effects_rendering_mode=None, dml_effects_rendering_mode=None, dml_rendering_mode=None, file_name=None, flat_opc_xml_mapping_only=None, iml_rendering_mode=None, save_format=None, update_created_time_property=None, update_fields=None, update_last_printed_property=None, update_last_saved_time_property=None, update_sdt_content=None, zip_output=None, color_mode=None, jpeg_quality=None, metafile_rendering_options=None, numeral_format=None, optimize_output=None, page_count=None, page_index=None, use_book_fold_printing_settings=None):  # noqa: E501
+    def __init__(self, allow_embedding_post_script_fonts=None, custom_time_zone_info_data=None, dml3_d_effects_rendering_mode=None, dml_effects_rendering_mode=None, dml_rendering_mode=None, file_name=None, flat_opc_xml_mapping_only=None, iml_rendering_mode=None, update_created_time_property=None, update_fields=None, update_last_printed_property=None, update_last_saved_time_property=None, update_sdt_content=None, zip_output=None, color_mode=None, jpeg_quality=None, metafile_rendering_options=None, numeral_format=None, optimize_output=None, page_count=None, page_index=None, use_book_fold_printing_settings=None):  # noqa: E501
         """PsSaveOptionsData - a model defined in Swagger"""  # noqa: E501
 
         self._allow_embedding_post_script_fonts = None
@@ -105,7 +105,6 @@ class PsSaveOptionsData(object):
         self._file_name = None
         self._flat_opc_xml_mapping_only = None
         self._iml_rendering_mode = None
-        self._save_format = None
         self._update_created_time_property = None
         self._update_fields = None
         self._update_last_printed_property = None
@@ -119,6 +118,7 @@ class PsSaveOptionsData(object):
         self._optimize_output = None
         self._page_count = None
         self._page_index = None
+        self._save_format = "ps"
         self._use_book_fold_printing_settings = None
         self.discriminator = None
 
@@ -138,8 +138,6 @@ class PsSaveOptionsData(object):
             self.flat_opc_xml_mapping_only = flat_opc_xml_mapping_only
         if iml_rendering_mode is not None:
             self.iml_rendering_mode = iml_rendering_mode
-        if save_format is not None:
-            self.save_format = save_format
         if update_created_time_property is not None:
             self.update_created_time_property = update_created_time_property
         if update_fields is not None:
@@ -263,7 +261,15 @@ class PsSaveOptionsData(object):
         :param dml_effects_rendering_mode: The dml_effects_rendering_mode of this PsSaveOptionsData.  # noqa: E501
         :type: str
         """
-        self._dml_effects_rendering_mode = dml_effects_rendering_mode
+        allowed_values = ["Simplified", "None", "Fine"]  # noqa: E501
+        if not dml_effects_rendering_mode.isdigit():
+            if dml_effects_rendering_mode not in allowed_values:
+                raise ValueError(
+                    "Invalid value for `dml_effects_rendering_mode` ({0}), must be one of {1}"  # noqa: E501
+                    .format(dml_effects_rendering_mode, allowed_values))
+            self._dml_effects_rendering_mode = dml_effects_rendering_mode
+        else:
+            self._dml_effects_rendering_mode = allowed_values[int(dml_effects_rendering_mode) if six.PY3 else long(dml_effects_rendering_mode)]
 
     @property
     def dml_rendering_mode(self):
@@ -285,7 +291,15 @@ class PsSaveOptionsData(object):
         :param dml_rendering_mode: The dml_rendering_mode of this PsSaveOptionsData.  # noqa: E501
         :type: str
         """
-        self._dml_rendering_mode = dml_rendering_mode
+        allowed_values = ["Fallback", "DrawingML"]  # noqa: E501
+        if not dml_rendering_mode.isdigit():
+            if dml_rendering_mode not in allowed_values:
+                raise ValueError(
+                    "Invalid value for `dml_rendering_mode` ({0}), must be one of {1}"  # noqa: E501
+                    .format(dml_rendering_mode, allowed_values))
+            self._dml_rendering_mode = dml_rendering_mode
+        else:
+            self._dml_rendering_mode = allowed_values[int(dml_rendering_mode) if six.PY3 else long(dml_rendering_mode)]
 
     @property
     def file_name(self):
@@ -351,29 +365,15 @@ class PsSaveOptionsData(object):
         :param iml_rendering_mode: The iml_rendering_mode of this PsSaveOptionsData.  # noqa: E501
         :type: str
         """
-        self._iml_rendering_mode = iml_rendering_mode
-
-    @property
-    def save_format(self):
-        """Gets the save_format of this PsSaveOptionsData.  # noqa: E501
-
-        Gets or sets the format of save.  # noqa: E501
-
-        :return: The save_format of this PsSaveOptionsData.  # noqa: E501
-        :rtype: str
-        """
-        return self._save_format
-
-    @save_format.setter
-    def save_format(self, save_format):
-        """Sets the save_format of this PsSaveOptionsData.
-
-        Gets or sets the format of save.  # noqa: E501
-
-        :param save_format: The save_format of this PsSaveOptionsData.  # noqa: E501
-        :type: str
-        """
-        self._save_format = save_format
+        allowed_values = ["Fallback", "InkML"]  # noqa: E501
+        if not iml_rendering_mode.isdigit():
+            if iml_rendering_mode not in allowed_values:
+                raise ValueError(
+                    "Invalid value for `iml_rendering_mode` ({0}), must be one of {1}"  # noqa: E501
+                    .format(iml_rendering_mode, allowed_values))
+            self._iml_rendering_mode = iml_rendering_mode
+        else:
+            self._iml_rendering_mode = allowed_values[int(iml_rendering_mode) if six.PY3 else long(iml_rendering_mode)]
 
     @property
     def update_created_time_property(self):
@@ -527,7 +527,15 @@ class PsSaveOptionsData(object):
         :param color_mode: The color_mode of this PsSaveOptionsData.  # noqa: E501
         :type: str
         """
-        self._color_mode = color_mode
+        allowed_values = ["Normal", "Grayscale"]  # noqa: E501
+        if not color_mode.isdigit():
+            if color_mode not in allowed_values:
+                raise ValueError(
+                    "Invalid value for `color_mode` ({0}), must be one of {1}"  # noqa: E501
+                    .format(color_mode, allowed_values))
+            self._color_mode = color_mode
+        else:
+            self._color_mode = allowed_values[int(color_mode) if six.PY3 else long(color_mode)]
 
     @property
     def jpeg_quality(self):
@@ -593,7 +601,15 @@ class PsSaveOptionsData(object):
         :param numeral_format: The numeral_format of this PsSaveOptionsData.  # noqa: E501
         :type: str
         """
-        self._numeral_format = numeral_format
+        allowed_values = ["European", "ArabicIndic", "EasternArabicIndic", "Context", "System"]  # noqa: E501
+        if not numeral_format.isdigit():
+            if numeral_format not in allowed_values:
+                raise ValueError(
+                    "Invalid value for `numeral_format` ({0}), must be one of {1}"  # noqa: E501
+                    .format(numeral_format, allowed_values))
+            self._numeral_format = numeral_format
+        else:
+            self._numeral_format = allowed_values[int(numeral_format) if six.PY3 else long(numeral_format)]
 
     @property
     def optimize_output(self):
@@ -661,6 +677,18 @@ class PsSaveOptionsData(object):
         """
         self._page_index = page_index
 
+    @property
+    def save_format(self):
+        """Gets the save_format of this PsSaveOptionsData.  # noqa: E501
+
+        Gets the format of save.  # noqa: E501
+
+        :return: The save_format of this PsSaveOptionsData.  # noqa: E501
+        :rtype: str
+        """
+        return self._save_format
+
+
     @property
     def use_book_fold_printing_settings(self):
         """Gets the use_book_fold_printing_settings of this PsSaveOptionsData.  # noqa: E501
