@@ -142,4 +142,4 @@ class ApplyStyleToDocumentElementRequest(BaseRequestObject):
         return 'WordsResponse'  # noqa: E501
 
     def deserialize_response(self, api_client, response):
-        return self.deserialize(response, WordsResponse, api_client)
+        return api_client.deserialize(response.data, response.getheaders(), WordsResponse)
