@@ -96,4 +96,4 @@ class ClassifyRequest(BaseRequestObject):
         return 'ClassificationResponse'  # noqa: E501
 
     def deserialize_response(self, api_client, response):
-        return self.deserialize(response, ClassificationResponse, api_client)
+        return api_client.deserialize(response.data, response.getheaders(), ClassificationResponse)
