@@ -125,4 +125,4 @@ class GetBorderRequest(BaseRequestObject):
         return 'BorderResponse'  # noqa: E501
 
     def deserialize_response(self, api_client, response):
-        return self.deserialize(response, BorderResponse, api_client)
+        return api_client.deserialize(response.data, response.getheaders(), BorderResponse)
