@@ -112,4 +112,4 @@ class GetCommentOnlineRequest(BaseRequestObject):
         return 'CommentResponse'  # noqa: E501
 
     def deserialize_response(self, api_client, response):
-        return self.deserialize(response, CommentResponse, api_client)
+        return api_client.deserialize(response.data, response.getheaders(), CommentResponse)
