@@ -81,4 +81,4 @@ class GetPublicKeyRequest(BaseRequestObject):
         return 'PublicKeyResponse'  # noqa: E501
 
     def deserialize_response(self, api_client, response):
-        return self.deserialize(response, PublicKeyResponse, api_client)
+        return api_client.deserialize(response.data, response.getheaders(), PublicKeyResponse)
