@@ -121,4 +121,4 @@ class GetTableCellOnlineRequest(BaseRequestObject):
         return 'TableCellResponse'  # noqa: E501
 
     def deserialize_response(self, api_client, response):
-        return self.deserialize(response, TableCellResponse, api_client)
+        return api_client.deserialize(response.data, response.getheaders(), TableCellResponse)
