@@ -131,5 +131,5 @@ class InsertOrUpdateParagraphTabStopOnlineRequest(BaseRequestObject):
     def deserialize_response(self, api_client, response):
         multipart = self.getparts(response)
         return InsertOrUpdateParagraphTabStopOnlineResponse(
-          self.deserialize(json.loads(multipart[0].text), TabStopsResponse, api_client),
-          self.deserialize_file(multipart[1].content, multipart[1].headers, api_client))
+          api_client.deserialize(api_client.findMultipartByName(multipart, "Model").content, api_client.findMultipartByName(multipart, "Model").headers, TabStopsResponse),
+          api_client.deserialize_files_collection(api_client.findMultipartByName(multipart, "Document").content, api_client.findMultipartByName(multipart, "Document").headers))
