@@ -140,4 +140,4 @@ class InsertOrUpdateParagraphTabStopRequest(BaseRequestObject):
         return 'TabStopsResponse'  # noqa: E501
 
     def deserialize_response(self, api_client, response):
-        return self.deserialize(response, TabStopsResponse, api_client)
+        return api_client.deserialize(response.data, response.getheaders(), TabStopsResponse)
