@@ -143,4 +143,4 @@ class InsertParagraphRequest(BaseRequestObject):
         return 'ParagraphResponse'  # noqa: E501
 
     def deserialize_response(self, api_client, response):
-        return self.deserialize(response, ParagraphResponse, api_client)
+        return api_client.deserialize(response.data, response.getheaders(), ParagraphResponse)
