@@ -193,4 +193,4 @@ class SaveAsTiffRequest(BaseRequestObject):
         return 'SaveResponse'  # noqa: E501
 
     def deserialize_response(self, api_client, response):
-        return self.deserialize(response, SaveResponse, api_client)
+        return api_client.deserialize(response.data, response.getheaders(), SaveResponse)
